#!/bin/sh 
# \
exec oagtclsh "$0" "$@"

if ![info exists env(OAG_TOP_DIR)] {
      set env(OAG_TOP_DIR) /usr/local
 }
set auto_path [linsert $auto_path 0  $env(OAG_TOP_DIR)/oag/apps/lib/$env(HOST_ARCH)]

APSStandardSetup

#set usage {usage: genOpt -input <filename> [-contin 1] [-errorFactor <number>] [-reduce 1] [-help 1] [-multiObjective <1|0>] [-topUp 1] [

set rootname mytest

set fd [open $rootname.plog a]

# tunes vs momentum.  This is simply to avoid major resonance
# crossings that might be stable (e.g., due to large tune shift
# with amplitude), but that make me nervous.

set deltaLimit 10e-2

  if {[file exists $rootname.w1] && [file exists $rootname.fin]} {
      exec sddscollapse $rootname.fin $rootname.finc

      # First, look for cases where the particle is lost and find the minimum
      # |delta| and store it in result
      if [catch {exec sddsprocess $rootname.finc -pipe=out -nowarning \
                   "-define=col,deltaAbs,MALIN.DP abs" \
                   -filter=column,Transmission,1,1,! \
                   -process=deltaAbs,min,%sMin \
                   | sdds2stream -pipe -parameter=deltaAbsMin} result] {
          puts "delta limit 1: $result"
      }

      #Check if large number or larger than deltaLimit
      puts $fd "Delta limit 1 : $result"
      if {![string match *e+308 $result] && [expr $result<$deltaLimit]} {
          set deltaLimit $result
      }

      # Second, look for undefined tunes
      if [catch {exec sddsnaff $rootname.w1 -pipe=out \
                   -column=Pass -pair=Cx,Cxp -pair=Cy,Cyp -terminate=frequencies=1 \
                   | sddscombine -pipe -merge \
                   | sddsxref -pipe $rootname.finc -take=MALIN.DP \
                   | sddsprocess -pipe "-define=column,deltaAbs,MALIN.DP abs" \
               -filter=col,deltaAbs,1e-3,1 \
                   | sddssort -pipe -column=deltaAbs \
                   | sddsprocess -nowarning -pipe=in $rootname.naff -process=C*Frequency,first,%s0 } result] {
          puts "delta limit 2: $result"
      }

      if [catch {exec sddsprocess -nowarning $rootname.naff -pipe=out -filter=col,CxFrequency,-1,-1,CyFrequency,-1,-1,|  \
                   -process=deltaAbs,min,%sMin \
               | sdds2stream -pipe -parameter=deltaAbsMin} result] {
          puts "delta limit 3: $result"
      }
      puts $fd "Delta limit 2: $result"
      if {![string match *e+308 $result] && [expr $result<$deltaLimit]} {
          set deltaLimit $result
      }

      # Look for integer or half-integer crossings
      foreach plane {x y} {
          if [catch {exec sddsprocess $rootname.naff -pipe=out -nowarning \
                       "-define=column,badTune,C${plane}Frequency 2 * int C${plane}Frequency0 2 * int - abs" \
                       -filter=col,badTune,1,1 \
                       -process=deltaAbs,min,%sMin \
                       | sdds2stream -pipe -parameter=deltaAbsMin} result] {
              puts "delta limit 4 ($plane): $result"
          }
          puts $fd "Delta limit 3 ($plane): $result"
      if {![string match *e+308 $result] && [expr $result<$deltaLimit]} {
              set deltaLimit $result
          }
      }
      puts $fd "New delta limit: $deltaLimit"
  }
